@@ -186,7 +186,9 @@ def set_attr(nested: List[Tuple[int, int, int, int]],
     return nested
 
 
-def adjac_to_nested_with_attr(adjac: List[Tuple[int, int, DATA]]
+def adjac_to_nested_with_attr(adjac: List[Tuple[int, int, DATA]],
+                              skip_id_ranges: bool = True,
+                              root_id: Optional[int] = 0
                               ) -> List[Tuple[int, int, int, int, DATA]]:
     """Convert Adjacancy List to Nested Set Table with data column
 
@@ -199,6 +201,13 @@ def adjac_to_nested_with_attr(adjac: List[Tuple[int, int, DATA]]
             1: Parent ID of the node
             2: Attributes related to the node ID
 
+    skip_id_ranges : bool (Default: True)
+        Ignore rows with id ranges, e.g. "5-6". see
+    https://universaldependencies.org/format.html#words-tokens-and-empty-nodes
+
+    root_id : int = 0
+        In CoNLL-U the root is usually "0"
+
     Return:
     -------
     nested : List[Tuple[int, int, int, int, DATA]]
@@ -216,6 +225,18 @@ def adjac_to_nested_with_attr(adjac: List[Tuple[int, int, DATA]]
         adjac = [(1, 2, 'A'), (2, 0, 'B'), (3, 2, 'C'), (4, 3, 'D')]
         nested = ts.adjac_to_nested_with_attr(adjac)
     """
-    nested = adjac_to_nested([(i, p) for i, p, _ in adjac])
+    if skip_id_ranges:
+        adjac = [(i, p, m) for i, p, m in adjac
+                 if not isinstance(i, (list, tuple))]
+    # Parse 1 dependency tree
+    nested = adjac_to_nested([(i, p) for i, p, _ in adjac], root_id=root_id)
+    # thrown an error
+    if len(adjac) > len(nested):
+        raise Exception((
+            "The provided adjacency matrix has more nodes than the produced "
+            "nested set list. The most likely cause is that the adjaceny "
+            "matrix contains 2 or more root nodes."))
+    # Add the deprel attribute
     nested = set_attr(nested, [(i, d) for i, _, d in adjac])
+    # done
     return nested
