@@ -1,12 +1,14 @@
 import json
 import hashlib
 from typing import List, Union
+import struct
 ELEMENT = Union[int, float, str, dict, list, tuple]
 
 
-def to_hash(tree: ELEMENT) -> hashlib.sha512:
+def to_hash(subtree: ELEMENT) -> hashlib.sha512:
     """Stringify and hash a python list"""
-    return hashlib.sha512(json.dumps(tree).encode('utf-8'))
+    stringified = json.dumps(subtree).encode('utf-8')
+    return hashlib.sha512(stringified)
 
 
 def unique_trees(trees: List[ELEMENT]) -> List[ELEMENT]:
@@ -17,3 +19,7 @@ def unique_trees(trees: List[ELEMENT]) -> List[ELEMENT]:
     hashed = {to_hash(tree).hexdigest(): tree for tree in trees}
     # read the original trees
     return [tree for _, tree in hashed.items()]
+
+
+def uint32_to_int32(i):  # i: np.uint32 -> np.int32
+    return struct.unpack('<l', struct.pack('<I', i))[0]
